@@ -1,6 +1,6 @@
 package Archive::Rgssad;
 
-use 5.010;
+use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
@@ -13,34 +13,23 @@ Archive::Rgssad - Provide an interface to rgssad and rgss2a archive files.
 
 =head1 VERSION
 
-Version 0.2.0
+Version 0.1
 
 =cut
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.1';
 
 
 =head1 SYNOPSIS
 
     use Archive::Rgssad;
 
-    my $rgssad = Archive::Rgssad->new('Game.rgssad');
-    for my $entry ($rgssad->entries) {
-      ...
-    }
+    my $foo = Archive::Rgssad->new();
+    ...
 
 =head1 SUBROUTINES/METHODS
 
-=head2 Constructor
-
-=over 4
-
-=item new([$io])
-
-Create an empty rgssad archive. If an additional argument is passed, call
-C<load> to load the entries from it.
-
-=back
+=head2 new
 
 =cut
 
@@ -56,14 +45,7 @@ sub new {
   return $self;
 }
 
-=head2 Load and Save
-
-=over 4
-
-=item load($io)
-
-Load entries from C<$io>, which should be either a readable instance of
-IO::Handle or its subclasses or a valid filepath.
+=head2 load
 
 =cut
 
@@ -92,8 +74,7 @@ sub load {
     $len = unpack('V', $buf) ^ keygen($key);
 
     $fh->read($buf, $len);
-    $_ = $key;
-    $buf ^= pack('V*', keygen($_, ($len + 3) / 4));
+    $buf ^= pack('V*', keygen($_ = $key, ($len + 3) / 4));
     $entry->data(substr($buf, 0, $len));
 
     push @entries, $entry;
@@ -103,12 +84,7 @@ sub load {
   $fh->close;
 }
 
-=item save($io)
-
-Save the entries to C<$io>, which should be either a writable instance of
-IO::Handle or its subclasses or a valid filepath.
-
-=back
+=head2 save
 
 =cut
 
@@ -133,21 +109,14 @@ sub save {
     $len = length $entry->data;
     $fh->write(pack('V', $len ^ keygen($key)), 4);
 
-    $_ = $key;
-    $buf = $entry->data ^ pack('V*', keygen($_, ($len + 3) / 4));
+    $buf = $entry->data ^ pack('V*', keygen($_ = $key, ($len + 3) / 4));
     $fh->write($buf, $len);
   }
 
   $fh->close;
 }
 
-=head2 Manipulate Entries
-
-=over 4
-
-=item entries
-
-Return all entries.
+=head2 entries
 
 =cut
 
@@ -156,10 +125,7 @@ sub entries {
   return @{$self->{entries}};
 }
 
-=item get($path)
-
-Return all entries with specified path. In scalar context, just return the
-first one.
+=head2 get
 
 =cut
 
@@ -170,11 +136,7 @@ sub get {
   return wantarray ? @ret : $ret[0];
 }
 
-=item add($path => $data, ...)
-
-=item add($entry, ...)
-
-Add new entries like $entry or Archive::Rgssad::Entry->new($path, $data).
+=head2 add
 
 =cut
 
@@ -183,21 +145,14 @@ sub add {
   while (@_ > 0) {
     $_ = shift;
     if (ref eq 'Archive::Rgssad::Entry') {
-      push @{$self->{entries}}, $_;
+      push $self->{entries}, $_;
     } else {
-      push @{$self->{entries}}, Archive::Rgssad::Entry->new($_, shift);
+      push $self->{entries}, Archive::Rgssad::Entry->new($_, shift);
     }
   }
 }
 
-=item remove($path)
-
-=item remove($entry)
-
-If an entry is passed, remove the entries with the same path and data.
-Otherwise, remove all entries with specified path.
-
-=back
+=head2 remove
 
 =cut
 
